Status Commands — MAX BLE HCI 0.1.0 documentation

# Status Commands

## Read RSSI

Read the Received Signal Strength Indication (RSSI) from the Controller.

Command | OCF | Command Parameters | Return Parameters
--- | --- | --- | ---
READ_RSSI | 0x0005 | Handle | Status Handle RSSI

### Parameters

Handle, size = 2 octets
Value(s) | Parameter Description
--- | ---
0x0000 to 0x0EFF | Connection handle for which the RSSI should be read.

### Return Parameters

Status, size = 1 octet
Value(s) | Parameter Description
--- | ---
0x00 | Command completed successfully
0x01 to 0xFF | Command failed.

Handle, size = 2 octets
Value(s) | Parameter Description
--- | ---
0x0000 to 0x0EFF | Connection handle for which RSSI has been read.

RSSI, size = 1 octet
Value(s) | Parameter Description
--- | ---
0x00 to 0xFF | RSSI (signed value). Range: -127dBm to 20dBm, 127 if invalid.

### Event(s) Generated

- COMMAND_COMPLETE